import * as z from "zod";
import { ClosedEnum } from "../types/enums.js";
import { Result as SafeParseResult } from "../types/fp.js";
import { SDKValidationError } from "./sdkvalidationerror.js";
export declare const Events: {
    readonly BudgetReached: "budget.reached";
    readonly BudgetReset: "budget.reset";
    readonly DomainCreated: "domain.created";
    readonly DeploymentCreated: "deployment.created";
    readonly DeploymentError: "deployment.error";
    readonly DeploymentCanceled: "deployment.canceled";
    readonly DeploymentSucceeded: "deployment.succeeded";
    readonly DeploymentReady: "deployment.ready";
    readonly DeploymentCheckRerequested: "deployment.check-rerequested";
    readonly DeploymentPromoted: "deployment.promoted";
    readonly DeploymentIntegrationActionStart: "deployment.integration.action.start";
    readonly DeploymentIntegrationActionCancel: "deployment.integration.action.cancel";
    readonly DeploymentIntegrationActionCleanup: "deployment.integration.action.cleanup";
    readonly EdgeConfigCreated: "edge-config.created";
    readonly EdgeConfigDeleted: "edge-config.deleted";
    readonly EdgeConfigItemsUpdated: "edge-config.items.updated";
    readonly FirewallAttack: "firewall.attack";
    readonly IntegrationConfigurationPermissionUpgraded: "integration-configuration.permission-upgraded";
    readonly IntegrationConfigurationRemoved: "integration-configuration.removed";
    readonly IntegrationConfigurationScopeChangeConfirmed: "integration-configuration.scope-change-confirmed";
    readonly IntegrationResourceProjectConnected: "integration-resource.project-connected";
    readonly IntegrationResourceProjectDisconnected: "integration-resource.project-disconnected";
    readonly ProjectCreated: "project.created";
    readonly ProjectRemoved: "project.removed";
    readonly ProjectDomainVerified: "project.domain.verified";
    readonly ProjectRollingReleaseStarted: "project.rolling-release.started";
    readonly ProjectRollingReleaseAborted: "project.rolling-release.aborted";
    readonly ProjectRollingReleaseCompleted: "project.rolling-release.completed";
    readonly ProjectRollingReleaseApproved: "project.rolling-release.approved";
    readonly DeploymentChecksCompletedLegacy: "deployment-checks-completed";
    readonly DeploymentReadyLegacy: "deployment-ready";
    readonly DeploymentPreparedLegacy: "deployment-prepared";
    readonly DeploymentErrorLegacy: "deployment-error";
    readonly DeploymentCheckRerequestedLegacy: "deployment-check-rerequested";
    readonly DeploymentCanceledLegacy: "deployment-canceled";
    readonly ProjectCreatedLegacy: "project-created";
    readonly ProjectRemovedLegacy: "project-removed";
    readonly DomainCreatedLegacy: "domain-created";
    readonly DeploymentLegacy: "deployment";
    readonly IntegrationConfigurationPermissionUpdatedLegacy: "integration-configuration-permission-updated";
    readonly IntegrationConfigurationRemovedLegacy: "integration-configuration-removed";
    readonly IntegrationConfigurationScopeChangeConfirmedLegacy: "integration-configuration-scope-change-confirmed";
    readonly MarketplaceInvoiceCreated: "marketplace.invoice.created";
    readonly MarketplaceInvoicePaid: "marketplace.invoice.paid";
    readonly MarketplaceInvoiceNotpaid: "marketplace.invoice.notpaid";
    readonly MarketplaceInvoiceRefunded: "marketplace.invoice.refunded";
    readonly ObservabilityAnomaly: "observability.anomaly";
    readonly TestWebhook: "test-webhook";
};
export type Events = ClosedEnum<typeof Events>;
export type CreateWebhookRequestBody = {
    url: string;
    events: Array<Events>;
    projectIds?: Array<string> | undefined;
};
export type CreateWebhookRequest = {
    /**
     * The Team identifier to perform the request on behalf of.
     */
    teamId?: string | undefined;
    /**
     * The Team slug to perform the request on behalf of.
     */
    slug?: string | undefined;
    requestBody: CreateWebhookRequestBody;
};
/**
 * The webhooks events
 */
export declare const CreateWebhookEvents: {
    readonly BudgetReached: "budget.reached";
    readonly BudgetReset: "budget.reset";
    readonly DomainCreated: "domain.created";
    readonly DeploymentCreated: "deployment.created";
    readonly DeploymentError: "deployment.error";
    readonly DeploymentCanceled: "deployment.canceled";
    readonly DeploymentSucceeded: "deployment.succeeded";
    readonly DeploymentReady: "deployment.ready";
    readonly DeploymentCheckRerequested: "deployment.check-rerequested";
    readonly DeploymentPromoted: "deployment.promoted";
    readonly DeploymentIntegrationActionStart: "deployment.integration.action.start";
    readonly DeploymentIntegrationActionCancel: "deployment.integration.action.cancel";
    readonly DeploymentIntegrationActionCleanup: "deployment.integration.action.cleanup";
    readonly EdgeConfigCreated: "edge-config.created";
    readonly EdgeConfigDeleted: "edge-config.deleted";
    readonly EdgeConfigItemsUpdated: "edge-config.items.updated";
    readonly FirewallAttack: "firewall.attack";
    readonly IntegrationConfigurationPermissionUpgraded: "integration-configuration.permission-upgraded";
    readonly IntegrationConfigurationRemoved: "integration-configuration.removed";
    readonly IntegrationConfigurationScopeChangeConfirmed: "integration-configuration.scope-change-confirmed";
    readonly IntegrationResourceProjectConnected: "integration-resource.project-connected";
    readonly IntegrationResourceProjectDisconnected: "integration-resource.project-disconnected";
    readonly ProjectCreated: "project.created";
    readonly ProjectRemoved: "project.removed";
    readonly ProjectDomainVerified: "project.domain.verified";
    readonly ProjectRollingReleaseStarted: "project.rolling-release.started";
    readonly ProjectRollingReleaseAborted: "project.rolling-release.aborted";
    readonly ProjectRollingReleaseCompleted: "project.rolling-release.completed";
    readonly ProjectRollingReleaseApproved: "project.rolling-release.approved";
    readonly DeploymentChecksCompletedLegacy: "deployment-checks-completed";
    readonly DeploymentReadyLegacy: "deployment-ready";
    readonly DeploymentPreparedLegacy: "deployment-prepared";
    readonly DeploymentErrorLegacy: "deployment-error";
    readonly DeploymentCheckRerequestedLegacy: "deployment-check-rerequested";
    readonly DeploymentCanceledLegacy: "deployment-canceled";
    readonly ProjectCreatedLegacy: "project-created";
    readonly ProjectRemovedLegacy: "project-removed";
    readonly DomainCreatedLegacy: "domain-created";
    readonly DeploymentLegacy: "deployment";
    readonly IntegrationConfigurationPermissionUpdatedLegacy: "integration-configuration-permission-updated";
    readonly IntegrationConfigurationRemovedLegacy: "integration-configuration-removed";
    readonly IntegrationConfigurationScopeChangeConfirmedLegacy: "integration-configuration-scope-change-confirmed";
    readonly MarketplaceInvoiceCreated: "marketplace.invoice.created";
    readonly MarketplaceInvoicePaid: "marketplace.invoice.paid";
    readonly MarketplaceInvoiceNotpaid: "marketplace.invoice.notpaid";
    readonly MarketplaceInvoiceRefunded: "marketplace.invoice.refunded";
    readonly ObservabilityAnomaly: "observability.anomaly";
    readonly TestWebhook: "test-webhook";
};
/**
 * The webhooks events
 */
export type CreateWebhookEvents = ClosedEnum<typeof CreateWebhookEvents>;
export type CreateWebhookResponseBody = {
    /**
     * The webhook secret used to sign the payload
     */
    secret: string;
    /**
     * The webhooks events
     */
    events: Array<CreateWebhookEvents>;
    /**
     * The webhook id
     */
    id: string;
    /**
     * A string with the URL of the webhook
     */
    url: string;
    /**
     * The unique ID of the team the webhook belongs to
     */
    ownerId: string;
    /**
     * A number containing the date when the webhook was created in in milliseconds
     */
    createdAt: number;
    /**
     * A number containing the date when the webhook was updated in in milliseconds
     */
    updatedAt: number;
    /**
     * The ID of the projects the webhook is associated with
     */
    projectIds?: Array<string> | undefined;
};
/** @internal */
export declare const Events$inboundSchema: z.ZodNativeEnum<typeof Events>;
/** @internal */
export declare const Events$outboundSchema: z.ZodNativeEnum<typeof Events>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace Events$ {
    /** @deprecated use `Events$inboundSchema` instead. */
    const inboundSchema: z.ZodNativeEnum<{
        readonly BudgetReached: "budget.reached";
        readonly BudgetReset: "budget.reset";
        readonly DomainCreated: "domain.created";
        readonly DeploymentCreated: "deployment.created";
        readonly DeploymentError: "deployment.error";
        readonly DeploymentCanceled: "deployment.canceled";
        readonly DeploymentSucceeded: "deployment.succeeded";
        readonly DeploymentReady: "deployment.ready";
        readonly DeploymentCheckRerequested: "deployment.check-rerequested";
        readonly DeploymentPromoted: "deployment.promoted";
        readonly DeploymentIntegrationActionStart: "deployment.integration.action.start";
        readonly DeploymentIntegrationActionCancel: "deployment.integration.action.cancel";
        readonly DeploymentIntegrationActionCleanup: "deployment.integration.action.cleanup";
        readonly EdgeConfigCreated: "edge-config.created";
        readonly EdgeConfigDeleted: "edge-config.deleted";
        readonly EdgeConfigItemsUpdated: "edge-config.items.updated";
        readonly FirewallAttack: "firewall.attack";
        readonly IntegrationConfigurationPermissionUpgraded: "integration-configuration.permission-upgraded";
        readonly IntegrationConfigurationRemoved: "integration-configuration.removed";
        readonly IntegrationConfigurationScopeChangeConfirmed: "integration-configuration.scope-change-confirmed";
        readonly IntegrationResourceProjectConnected: "integration-resource.project-connected";
        readonly IntegrationResourceProjectDisconnected: "integration-resource.project-disconnected";
        readonly ProjectCreated: "project.created";
        readonly ProjectRemoved: "project.removed";
        readonly ProjectDomainVerified: "project.domain.verified";
        readonly ProjectRollingReleaseStarted: "project.rolling-release.started";
        readonly ProjectRollingReleaseAborted: "project.rolling-release.aborted";
        readonly ProjectRollingReleaseCompleted: "project.rolling-release.completed";
        readonly ProjectRollingReleaseApproved: "project.rolling-release.approved";
        readonly DeploymentChecksCompletedLegacy: "deployment-checks-completed";
        readonly DeploymentReadyLegacy: "deployment-ready";
        readonly DeploymentPreparedLegacy: "deployment-prepared";
        readonly DeploymentErrorLegacy: "deployment-error";
        readonly DeploymentCheckRerequestedLegacy: "deployment-check-rerequested";
        readonly DeploymentCanceledLegacy: "deployment-canceled";
        readonly ProjectCreatedLegacy: "project-created";
        readonly ProjectRemovedLegacy: "project-removed";
        readonly DomainCreatedLegacy: "domain-created";
        readonly DeploymentLegacy: "deployment";
        readonly IntegrationConfigurationPermissionUpdatedLegacy: "integration-configuration-permission-updated";
        readonly IntegrationConfigurationRemovedLegacy: "integration-configuration-removed";
        readonly IntegrationConfigurationScopeChangeConfirmedLegacy: "integration-configuration-scope-change-confirmed";
        readonly MarketplaceInvoiceCreated: "marketplace.invoice.created";
        readonly MarketplaceInvoicePaid: "marketplace.invoice.paid";
        readonly MarketplaceInvoiceNotpaid: "marketplace.invoice.notpaid";
        readonly MarketplaceInvoiceRefunded: "marketplace.invoice.refunded";
        readonly ObservabilityAnomaly: "observability.anomaly";
        readonly TestWebhook: "test-webhook";
    }>;
    /** @deprecated use `Events$outboundSchema` instead. */
    const outboundSchema: z.ZodNativeEnum<{
        readonly BudgetReached: "budget.reached";
        readonly BudgetReset: "budget.reset";
        readonly DomainCreated: "domain.created";
        readonly DeploymentCreated: "deployment.created";
        readonly DeploymentError: "deployment.error";
        readonly DeploymentCanceled: "deployment.canceled";
        readonly DeploymentSucceeded: "deployment.succeeded";
        readonly DeploymentReady: "deployment.ready";
        readonly DeploymentCheckRerequested: "deployment.check-rerequested";
        readonly DeploymentPromoted: "deployment.promoted";
        readonly DeploymentIntegrationActionStart: "deployment.integration.action.start";
        readonly DeploymentIntegrationActionCancel: "deployment.integration.action.cancel";
        readonly DeploymentIntegrationActionCleanup: "deployment.integration.action.cleanup";
        readonly EdgeConfigCreated: "edge-config.created";
        readonly EdgeConfigDeleted: "edge-config.deleted";
        readonly EdgeConfigItemsUpdated: "edge-config.items.updated";
        readonly FirewallAttack: "firewall.attack";
        readonly IntegrationConfigurationPermissionUpgraded: "integration-configuration.permission-upgraded";
        readonly IntegrationConfigurationRemoved: "integration-configuration.removed";
        readonly IntegrationConfigurationScopeChangeConfirmed: "integration-configuration.scope-change-confirmed";
        readonly IntegrationResourceProjectConnected: "integration-resource.project-connected";
        readonly IntegrationResourceProjectDisconnected: "integration-resource.project-disconnected";
        readonly ProjectCreated: "project.created";
        readonly ProjectRemoved: "project.removed";
        readonly ProjectDomainVerified: "project.domain.verified";
        readonly ProjectRollingReleaseStarted: "project.rolling-release.started";
        readonly ProjectRollingReleaseAborted: "project.rolling-release.aborted";
        readonly ProjectRollingReleaseCompleted: "project.rolling-release.completed";
        readonly ProjectRollingReleaseApproved: "project.rolling-release.approved";
        readonly DeploymentChecksCompletedLegacy: "deployment-checks-completed";
        readonly DeploymentReadyLegacy: "deployment-ready";
        readonly DeploymentPreparedLegacy: "deployment-prepared";
        readonly DeploymentErrorLegacy: "deployment-error";
        readonly DeploymentCheckRerequestedLegacy: "deployment-check-rerequested";
        readonly DeploymentCanceledLegacy: "deployment-canceled";
        readonly ProjectCreatedLegacy: "project-created";
        readonly ProjectRemovedLegacy: "project-removed";
        readonly DomainCreatedLegacy: "domain-created";
        readonly DeploymentLegacy: "deployment";
        readonly IntegrationConfigurationPermissionUpdatedLegacy: "integration-configuration-permission-updated";
        readonly IntegrationConfigurationRemovedLegacy: "integration-configuration-removed";
        readonly IntegrationConfigurationScopeChangeConfirmedLegacy: "integration-configuration-scope-change-confirmed";
        readonly MarketplaceInvoiceCreated: "marketplace.invoice.created";
        readonly MarketplaceInvoicePaid: "marketplace.invoice.paid";
        readonly MarketplaceInvoiceNotpaid: "marketplace.invoice.notpaid";
        readonly MarketplaceInvoiceRefunded: "marketplace.invoice.refunded";
        readonly ObservabilityAnomaly: "observability.anomaly";
        readonly TestWebhook: "test-webhook";
    }>;
}
/** @internal */
export declare const CreateWebhookRequestBody$inboundSchema: z.ZodType<CreateWebhookRequestBody, z.ZodTypeDef, unknown>;
/** @internal */
export type CreateWebhookRequestBody$Outbound = {
    url: string;
    events: Array<string>;
    projectIds?: Array<string> | undefined;
};
/** @internal */
export declare const CreateWebhookRequestBody$outboundSchema: z.ZodType<CreateWebhookRequestBody$Outbound, z.ZodTypeDef, CreateWebhookRequestBody>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace CreateWebhookRequestBody$ {
    /** @deprecated use `CreateWebhookRequestBody$inboundSchema` instead. */
    const inboundSchema: z.ZodType<CreateWebhookRequestBody, z.ZodTypeDef, unknown>;
    /** @deprecated use `CreateWebhookRequestBody$outboundSchema` instead. */
    const outboundSchema: z.ZodType<CreateWebhookRequestBody$Outbound, z.ZodTypeDef, CreateWebhookRequestBody>;
    /** @deprecated use `CreateWebhookRequestBody$Outbound` instead. */
    type Outbound = CreateWebhookRequestBody$Outbound;
}
export declare function createWebhookRequestBodyToJSON(createWebhookRequestBody: CreateWebhookRequestBody): string;
export declare function createWebhookRequestBodyFromJSON(jsonString: string): SafeParseResult<CreateWebhookRequestBody, SDKValidationError>;
/** @internal */
export declare const CreateWebhookRequest$inboundSchema: z.ZodType<CreateWebhookRequest, z.ZodTypeDef, unknown>;
/** @internal */
export type CreateWebhookRequest$Outbound = {
    teamId?: string | undefined;
    slug?: string | undefined;
    RequestBody: CreateWebhookRequestBody$Outbound;
};
/** @internal */
export declare const CreateWebhookRequest$outboundSchema: z.ZodType<CreateWebhookRequest$Outbound, z.ZodTypeDef, CreateWebhookRequest>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace CreateWebhookRequest$ {
    /** @deprecated use `CreateWebhookRequest$inboundSchema` instead. */
    const inboundSchema: z.ZodType<CreateWebhookRequest, z.ZodTypeDef, unknown>;
    /** @deprecated use `CreateWebhookRequest$outboundSchema` instead. */
    const outboundSchema: z.ZodType<CreateWebhookRequest$Outbound, z.ZodTypeDef, CreateWebhookRequest>;
    /** @deprecated use `CreateWebhookRequest$Outbound` instead. */
    type Outbound = CreateWebhookRequest$Outbound;
}
export declare function createWebhookRequestToJSON(createWebhookRequest: CreateWebhookRequest): string;
export declare function createWebhookRequestFromJSON(jsonString: string): SafeParseResult<CreateWebhookRequest, SDKValidationError>;
/** @internal */
export declare const CreateWebhookEvents$inboundSchema: z.ZodNativeEnum<typeof CreateWebhookEvents>;
/** @internal */
export declare const CreateWebhookEvents$outboundSchema: z.ZodNativeEnum<typeof CreateWebhookEvents>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace CreateWebhookEvents$ {
    /** @deprecated use `CreateWebhookEvents$inboundSchema` instead. */
    const inboundSchema: z.ZodNativeEnum<{
        readonly BudgetReached: "budget.reached";
        readonly BudgetReset: "budget.reset";
        readonly DomainCreated: "domain.created";
        readonly DeploymentCreated: "deployment.created";
        readonly DeploymentError: "deployment.error";
        readonly DeploymentCanceled: "deployment.canceled";
        readonly DeploymentSucceeded: "deployment.succeeded";
        readonly DeploymentReady: "deployment.ready";
        readonly DeploymentCheckRerequested: "deployment.check-rerequested";
        readonly DeploymentPromoted: "deployment.promoted";
        readonly DeploymentIntegrationActionStart: "deployment.integration.action.start";
        readonly DeploymentIntegrationActionCancel: "deployment.integration.action.cancel";
        readonly DeploymentIntegrationActionCleanup: "deployment.integration.action.cleanup";
        readonly EdgeConfigCreated: "edge-config.created";
        readonly EdgeConfigDeleted: "edge-config.deleted";
        readonly EdgeConfigItemsUpdated: "edge-config.items.updated";
        readonly FirewallAttack: "firewall.attack";
        readonly IntegrationConfigurationPermissionUpgraded: "integration-configuration.permission-upgraded";
        readonly IntegrationConfigurationRemoved: "integration-configuration.removed";
        readonly IntegrationConfigurationScopeChangeConfirmed: "integration-configuration.scope-change-confirmed";
        readonly IntegrationResourceProjectConnected: "integration-resource.project-connected";
        readonly IntegrationResourceProjectDisconnected: "integration-resource.project-disconnected";
        readonly ProjectCreated: "project.created";
        readonly ProjectRemoved: "project.removed";
        readonly ProjectDomainVerified: "project.domain.verified";
        readonly ProjectRollingReleaseStarted: "project.rolling-release.started";
        readonly ProjectRollingReleaseAborted: "project.rolling-release.aborted";
        readonly ProjectRollingReleaseCompleted: "project.rolling-release.completed";
        readonly ProjectRollingReleaseApproved: "project.rolling-release.approved";
        readonly DeploymentChecksCompletedLegacy: "deployment-checks-completed";
        readonly DeploymentReadyLegacy: "deployment-ready";
        readonly DeploymentPreparedLegacy: "deployment-prepared";
        readonly DeploymentErrorLegacy: "deployment-error";
        readonly DeploymentCheckRerequestedLegacy: "deployment-check-rerequested";
        readonly DeploymentCanceledLegacy: "deployment-canceled";
        readonly ProjectCreatedLegacy: "project-created";
        readonly ProjectRemovedLegacy: "project-removed";
        readonly DomainCreatedLegacy: "domain-created";
        readonly DeploymentLegacy: "deployment";
        readonly IntegrationConfigurationPermissionUpdatedLegacy: "integration-configuration-permission-updated";
        readonly IntegrationConfigurationRemovedLegacy: "integration-configuration-removed";
        readonly IntegrationConfigurationScopeChangeConfirmedLegacy: "integration-configuration-scope-change-confirmed";
        readonly MarketplaceInvoiceCreated: "marketplace.invoice.created";
        readonly MarketplaceInvoicePaid: "marketplace.invoice.paid";
        readonly MarketplaceInvoiceNotpaid: "marketplace.invoice.notpaid";
        readonly MarketplaceInvoiceRefunded: "marketplace.invoice.refunded";
        readonly ObservabilityAnomaly: "observability.anomaly";
        readonly TestWebhook: "test-webhook";
    }>;
    /** @deprecated use `CreateWebhookEvents$outboundSchema` instead. */
    const outboundSchema: z.ZodNativeEnum<{
        readonly BudgetReached: "budget.reached";
        readonly BudgetReset: "budget.reset";
        readonly DomainCreated: "domain.created";
        readonly DeploymentCreated: "deployment.created";
        readonly DeploymentError: "deployment.error";
        readonly DeploymentCanceled: "deployment.canceled";
        readonly DeploymentSucceeded: "deployment.succeeded";
        readonly DeploymentReady: "deployment.ready";
        readonly DeploymentCheckRerequested: "deployment.check-rerequested";
        readonly DeploymentPromoted: "deployment.promoted";
        readonly DeploymentIntegrationActionStart: "deployment.integration.action.start";
        readonly DeploymentIntegrationActionCancel: "deployment.integration.action.cancel";
        readonly DeploymentIntegrationActionCleanup: "deployment.integration.action.cleanup";
        readonly EdgeConfigCreated: "edge-config.created";
        readonly EdgeConfigDeleted: "edge-config.deleted";
        readonly EdgeConfigItemsUpdated: "edge-config.items.updated";
        readonly FirewallAttack: "firewall.attack";
        readonly IntegrationConfigurationPermissionUpgraded: "integration-configuration.permission-upgraded";
        readonly IntegrationConfigurationRemoved: "integration-configuration.removed";
        readonly IntegrationConfigurationScopeChangeConfirmed: "integration-configuration.scope-change-confirmed";
        readonly IntegrationResourceProjectConnected: "integration-resource.project-connected";
        readonly IntegrationResourceProjectDisconnected: "integration-resource.project-disconnected";
        readonly ProjectCreated: "project.created";
        readonly ProjectRemoved: "project.removed";
        readonly ProjectDomainVerified: "project.domain.verified";
        readonly ProjectRollingReleaseStarted: "project.rolling-release.started";
        readonly ProjectRollingReleaseAborted: "project.rolling-release.aborted";
        readonly ProjectRollingReleaseCompleted: "project.rolling-release.completed";
        readonly ProjectRollingReleaseApproved: "project.rolling-release.approved";
        readonly DeploymentChecksCompletedLegacy: "deployment-checks-completed";
        readonly DeploymentReadyLegacy: "deployment-ready";
        readonly DeploymentPreparedLegacy: "deployment-prepared";
        readonly DeploymentErrorLegacy: "deployment-error";
        readonly DeploymentCheckRerequestedLegacy: "deployment-check-rerequested";
        readonly DeploymentCanceledLegacy: "deployment-canceled";
        readonly ProjectCreatedLegacy: "project-created";
        readonly ProjectRemovedLegacy: "project-removed";
        readonly DomainCreatedLegacy: "domain-created";
        readonly DeploymentLegacy: "deployment";
        readonly IntegrationConfigurationPermissionUpdatedLegacy: "integration-configuration-permission-updated";
        readonly IntegrationConfigurationRemovedLegacy: "integration-configuration-removed";
        readonly IntegrationConfigurationScopeChangeConfirmedLegacy: "integration-configuration-scope-change-confirmed";
        readonly MarketplaceInvoiceCreated: "marketplace.invoice.created";
        readonly MarketplaceInvoicePaid: "marketplace.invoice.paid";
        readonly MarketplaceInvoiceNotpaid: "marketplace.invoice.notpaid";
        readonly MarketplaceInvoiceRefunded: "marketplace.invoice.refunded";
        readonly ObservabilityAnomaly: "observability.anomaly";
        readonly TestWebhook: "test-webhook";
    }>;
}
/** @internal */
export declare const CreateWebhookResponseBody$inboundSchema: z.ZodType<CreateWebhookResponseBody, z.ZodTypeDef, unknown>;
/** @internal */
export type CreateWebhookResponseBody$Outbound = {
    secret: string;
    events: Array<string>;
    id: string;
    url: string;
    ownerId: string;
    createdAt: number;
    updatedAt: number;
    projectIds?: Array<string> | undefined;
};
/** @internal */
export declare const CreateWebhookResponseBody$outboundSchema: z.ZodType<CreateWebhookResponseBody$Outbound, z.ZodTypeDef, CreateWebhookResponseBody>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace CreateWebhookResponseBody$ {
    /** @deprecated use `CreateWebhookResponseBody$inboundSchema` instead. */
    const inboundSchema: z.ZodType<CreateWebhookResponseBody, z.ZodTypeDef, unknown>;
    /** @deprecated use `CreateWebhookResponseBody$outboundSchema` instead. */
    const outboundSchema: z.ZodType<CreateWebhookResponseBody$Outbound, z.ZodTypeDef, CreateWebhookResponseBody>;
    /** @deprecated use `CreateWebhookResponseBody$Outbound` instead. */
    type Outbound = CreateWebhookResponseBody$Outbound;
}
export declare function createWebhookResponseBodyToJSON(createWebhookResponseBody: CreateWebhookResponseBody): string;
export declare function createWebhookResponseBodyFromJSON(jsonString: string): SafeParseResult<CreateWebhookResponseBody, SDKValidationError>;
//# sourceMappingURL=createwebhookop.d.ts.map