import * as z from "zod";
import { Result as SafeParseResult } from "../types/fp.js";
import { EdgeConfigItemValue, EdgeConfigItemValue$Outbound } from "./edgeconfigitemvalue.js";
import { SDKValidationError } from "./sdkvalidationerror.js";
export type GetEdgeConfigBackupRequest = {
    edgeConfigId: string;
    edgeConfigBackupVersionId: string;
    /**
     * The Team identifier to perform the request on behalf of.
     */
    teamId?: string | undefined;
    /**
     * The Team slug to perform the request on behalf of.
     */
    slug?: string | undefined;
};
export type ResponseBodyUser = {
    id: string;
    username: string;
    email: string;
    name?: string | undefined;
    avatar?: string | undefined;
};
export type ResponseBodyItems = {
    updatedAt: number;
    value: EdgeConfigItemValue | null;
    description?: string | undefined;
    createdAt: number;
};
export type ResponseBodyBackup = {
    digest: string;
    items: {
        [k: string]: ResponseBodyItems;
    };
    /**
     * Name for the Edge Config Names are not unique. Must start with an alphabetic character and can contain only alphanumeric characters and underscores).
     */
    slug: string;
    updatedAt: number;
};
export type ResponseBodyMetadata = {
    updatedAt?: string | undefined;
    updatedBy?: string | undefined;
    itemsCount?: number | undefined;
    itemsBytes?: number | undefined;
};
export type GetEdgeConfigBackupResponseBody2 = {
    user: ResponseBodyUser;
    id: string;
    lastModified: number;
    backup: ResponseBodyBackup;
    metadata: ResponseBodyMetadata;
};
export type GetEdgeConfigBackupResponseBodyItems = {
    updatedAt: number;
    value: EdgeConfigItemValue | null;
    description?: string | undefined;
    createdAt: number;
};
export type Backup = {
    digest: string;
    items: {
        [k: string]: GetEdgeConfigBackupResponseBodyItems;
    };
    /**
     * Name for the Edge Config Names are not unique. Must start with an alphabetic character and can contain only alphanumeric characters and underscores).
     */
    slug: string;
    updatedAt: number;
};
export type Metadata = {
    updatedAt?: string | undefined;
    updatedBy?: string | undefined;
    itemsCount?: number | undefined;
    itemsBytes?: number | undefined;
};
export type GetEdgeConfigBackupResponseBodyUser = {
    id: string;
    username: string;
    email: string;
    name?: string | undefined;
    avatar?: string | undefined;
};
/**
 * The object the API responds with when requesting an Edge Config backup
 */
export type GetEdgeConfigBackupResponseBody1 = {
    id: string;
    lastModified: number;
    backup: Backup;
    metadata: Metadata;
    user?: GetEdgeConfigBackupResponseBodyUser | undefined;
};
export type GetEdgeConfigBackupResponseBody = GetEdgeConfigBackupResponseBody1 | GetEdgeConfigBackupResponseBody2;
/** @internal */
export declare const GetEdgeConfigBackupRequest$inboundSchema: z.ZodType<GetEdgeConfigBackupRequest, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigBackupRequest$Outbound = {
    edgeConfigId: string;
    edgeConfigBackupVersionId: string;
    teamId?: string | undefined;
    slug?: string | undefined;
};
/** @internal */
export declare const GetEdgeConfigBackupRequest$outboundSchema: z.ZodType<GetEdgeConfigBackupRequest$Outbound, z.ZodTypeDef, GetEdgeConfigBackupRequest>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigBackupRequest$ {
    /** @deprecated use `GetEdgeConfigBackupRequest$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigBackupRequest, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigBackupRequest$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigBackupRequest$Outbound, z.ZodTypeDef, GetEdgeConfigBackupRequest>;
    /** @deprecated use `GetEdgeConfigBackupRequest$Outbound` instead. */
    type Outbound = GetEdgeConfigBackupRequest$Outbound;
}
export declare function getEdgeConfigBackupRequestToJSON(getEdgeConfigBackupRequest: GetEdgeConfigBackupRequest): string;
export declare function getEdgeConfigBackupRequestFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigBackupRequest, SDKValidationError>;
/** @internal */
export declare const ResponseBodyUser$inboundSchema: z.ZodType<ResponseBodyUser, z.ZodTypeDef, unknown>;
/** @internal */
export type ResponseBodyUser$Outbound = {
    id: string;
    username: string;
    email: string;
    name?: string | undefined;
    avatar?: string | undefined;
};
/** @internal */
export declare const ResponseBodyUser$outboundSchema: z.ZodType<ResponseBodyUser$Outbound, z.ZodTypeDef, ResponseBodyUser>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace ResponseBodyUser$ {
    /** @deprecated use `ResponseBodyUser$inboundSchema` instead. */
    const inboundSchema: z.ZodType<ResponseBodyUser, z.ZodTypeDef, unknown>;
    /** @deprecated use `ResponseBodyUser$outboundSchema` instead. */
    const outboundSchema: z.ZodType<ResponseBodyUser$Outbound, z.ZodTypeDef, ResponseBodyUser>;
    /** @deprecated use `ResponseBodyUser$Outbound` instead. */
    type Outbound = ResponseBodyUser$Outbound;
}
export declare function responseBodyUserToJSON(responseBodyUser: ResponseBodyUser): string;
export declare function responseBodyUserFromJSON(jsonString: string): SafeParseResult<ResponseBodyUser, SDKValidationError>;
/** @internal */
export declare const ResponseBodyItems$inboundSchema: z.ZodType<ResponseBodyItems, z.ZodTypeDef, unknown>;
/** @internal */
export type ResponseBodyItems$Outbound = {
    updatedAt: number;
    value: EdgeConfigItemValue$Outbound | null;
    description?: string | undefined;
    createdAt: number;
};
/** @internal */
export declare const ResponseBodyItems$outboundSchema: z.ZodType<ResponseBodyItems$Outbound, z.ZodTypeDef, ResponseBodyItems>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace ResponseBodyItems$ {
    /** @deprecated use `ResponseBodyItems$inboundSchema` instead. */
    const inboundSchema: z.ZodType<ResponseBodyItems, z.ZodTypeDef, unknown>;
    /** @deprecated use `ResponseBodyItems$outboundSchema` instead. */
    const outboundSchema: z.ZodType<ResponseBodyItems$Outbound, z.ZodTypeDef, ResponseBodyItems>;
    /** @deprecated use `ResponseBodyItems$Outbound` instead. */
    type Outbound = ResponseBodyItems$Outbound;
}
export declare function responseBodyItemsToJSON(responseBodyItems: ResponseBodyItems): string;
export declare function responseBodyItemsFromJSON(jsonString: string): SafeParseResult<ResponseBodyItems, SDKValidationError>;
/** @internal */
export declare const ResponseBodyBackup$inboundSchema: z.ZodType<ResponseBodyBackup, z.ZodTypeDef, unknown>;
/** @internal */
export type ResponseBodyBackup$Outbound = {
    digest: string;
    items: {
        [k: string]: ResponseBodyItems$Outbound;
    };
    slug: string;
    updatedAt: number;
};
/** @internal */
export declare const ResponseBodyBackup$outboundSchema: z.ZodType<ResponseBodyBackup$Outbound, z.ZodTypeDef, ResponseBodyBackup>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace ResponseBodyBackup$ {
    /** @deprecated use `ResponseBodyBackup$inboundSchema` instead. */
    const inboundSchema: z.ZodType<ResponseBodyBackup, z.ZodTypeDef, unknown>;
    /** @deprecated use `ResponseBodyBackup$outboundSchema` instead. */
    const outboundSchema: z.ZodType<ResponseBodyBackup$Outbound, z.ZodTypeDef, ResponseBodyBackup>;
    /** @deprecated use `ResponseBodyBackup$Outbound` instead. */
    type Outbound = ResponseBodyBackup$Outbound;
}
export declare function responseBodyBackupToJSON(responseBodyBackup: ResponseBodyBackup): string;
export declare function responseBodyBackupFromJSON(jsonString: string): SafeParseResult<ResponseBodyBackup, SDKValidationError>;
/** @internal */
export declare const ResponseBodyMetadata$inboundSchema: z.ZodType<ResponseBodyMetadata, z.ZodTypeDef, unknown>;
/** @internal */
export type ResponseBodyMetadata$Outbound = {
    updatedAt?: string | undefined;
    updatedBy?: string | undefined;
    itemsCount?: number | undefined;
    itemsBytes?: number | undefined;
};
/** @internal */
export declare const ResponseBodyMetadata$outboundSchema: z.ZodType<ResponseBodyMetadata$Outbound, z.ZodTypeDef, ResponseBodyMetadata>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace ResponseBodyMetadata$ {
    /** @deprecated use `ResponseBodyMetadata$inboundSchema` instead. */
    const inboundSchema: z.ZodType<ResponseBodyMetadata, z.ZodTypeDef, unknown>;
    /** @deprecated use `ResponseBodyMetadata$outboundSchema` instead. */
    const outboundSchema: z.ZodType<ResponseBodyMetadata$Outbound, z.ZodTypeDef, ResponseBodyMetadata>;
    /** @deprecated use `ResponseBodyMetadata$Outbound` instead. */
    type Outbound = ResponseBodyMetadata$Outbound;
}
export declare function responseBodyMetadataToJSON(responseBodyMetadata: ResponseBodyMetadata): string;
export declare function responseBodyMetadataFromJSON(jsonString: string): SafeParseResult<ResponseBodyMetadata, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigBackupResponseBody2$inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody2, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigBackupResponseBody2$Outbound = {
    user: ResponseBodyUser$Outbound;
    id: string;
    lastModified: number;
    backup: ResponseBodyBackup$Outbound;
    metadata: ResponseBodyMetadata$Outbound;
};
/** @internal */
export declare const GetEdgeConfigBackupResponseBody2$outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody2$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBody2>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigBackupResponseBody2$ {
    /** @deprecated use `GetEdgeConfigBackupResponseBody2$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody2, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigBackupResponseBody2$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody2$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBody2>;
    /** @deprecated use `GetEdgeConfigBackupResponseBody2$Outbound` instead. */
    type Outbound = GetEdgeConfigBackupResponseBody2$Outbound;
}
export declare function getEdgeConfigBackupResponseBody2ToJSON(getEdgeConfigBackupResponseBody2: GetEdgeConfigBackupResponseBody2): string;
export declare function getEdgeConfigBackupResponseBody2FromJSON(jsonString: string): SafeParseResult<GetEdgeConfigBackupResponseBody2, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigBackupResponseBodyItems$inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBodyItems, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigBackupResponseBodyItems$Outbound = {
    updatedAt: number;
    value: EdgeConfigItemValue$Outbound | null;
    description?: string | undefined;
    createdAt: number;
};
/** @internal */
export declare const GetEdgeConfigBackupResponseBodyItems$outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBodyItems$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBodyItems>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigBackupResponseBodyItems$ {
    /** @deprecated use `GetEdgeConfigBackupResponseBodyItems$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBodyItems, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigBackupResponseBodyItems$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBodyItems$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBodyItems>;
    /** @deprecated use `GetEdgeConfigBackupResponseBodyItems$Outbound` instead. */
    type Outbound = GetEdgeConfigBackupResponseBodyItems$Outbound;
}
export declare function getEdgeConfigBackupResponseBodyItemsToJSON(getEdgeConfigBackupResponseBodyItems: GetEdgeConfigBackupResponseBodyItems): string;
export declare function getEdgeConfigBackupResponseBodyItemsFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigBackupResponseBodyItems, SDKValidationError>;
/** @internal */
export declare const Backup$inboundSchema: z.ZodType<Backup, z.ZodTypeDef, unknown>;
/** @internal */
export type Backup$Outbound = {
    digest: string;
    items: {
        [k: string]: GetEdgeConfigBackupResponseBodyItems$Outbound;
    };
    slug: string;
    updatedAt: number;
};
/** @internal */
export declare const Backup$outboundSchema: z.ZodType<Backup$Outbound, z.ZodTypeDef, Backup>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace Backup$ {
    /** @deprecated use `Backup$inboundSchema` instead. */
    const inboundSchema: z.ZodType<Backup, z.ZodTypeDef, unknown>;
    /** @deprecated use `Backup$outboundSchema` instead. */
    const outboundSchema: z.ZodType<Backup$Outbound, z.ZodTypeDef, Backup>;
    /** @deprecated use `Backup$Outbound` instead. */
    type Outbound = Backup$Outbound;
}
export declare function backupToJSON(backup: Backup): string;
export declare function backupFromJSON(jsonString: string): SafeParseResult<Backup, SDKValidationError>;
/** @internal */
export declare const Metadata$inboundSchema: z.ZodType<Metadata, z.ZodTypeDef, unknown>;
/** @internal */
export type Metadata$Outbound = {
    updatedAt?: string | undefined;
    updatedBy?: string | undefined;
    itemsCount?: number | undefined;
    itemsBytes?: number | undefined;
};
/** @internal */
export declare const Metadata$outboundSchema: z.ZodType<Metadata$Outbound, z.ZodTypeDef, Metadata>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace Metadata$ {
    /** @deprecated use `Metadata$inboundSchema` instead. */
    const inboundSchema: z.ZodType<Metadata, z.ZodTypeDef, unknown>;
    /** @deprecated use `Metadata$outboundSchema` instead. */
    const outboundSchema: z.ZodType<Metadata$Outbound, z.ZodTypeDef, Metadata>;
    /** @deprecated use `Metadata$Outbound` instead. */
    type Outbound = Metadata$Outbound;
}
export declare function metadataToJSON(metadata: Metadata): string;
export declare function metadataFromJSON(jsonString: string): SafeParseResult<Metadata, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigBackupResponseBodyUser$inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBodyUser, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigBackupResponseBodyUser$Outbound = {
    id: string;
    username: string;
    email: string;
    name?: string | undefined;
    avatar?: string | undefined;
};
/** @internal */
export declare const GetEdgeConfigBackupResponseBodyUser$outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBodyUser$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBodyUser>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigBackupResponseBodyUser$ {
    /** @deprecated use `GetEdgeConfigBackupResponseBodyUser$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBodyUser, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigBackupResponseBodyUser$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBodyUser$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBodyUser>;
    /** @deprecated use `GetEdgeConfigBackupResponseBodyUser$Outbound` instead. */
    type Outbound = GetEdgeConfigBackupResponseBodyUser$Outbound;
}
export declare function getEdgeConfigBackupResponseBodyUserToJSON(getEdgeConfigBackupResponseBodyUser: GetEdgeConfigBackupResponseBodyUser): string;
export declare function getEdgeConfigBackupResponseBodyUserFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigBackupResponseBodyUser, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigBackupResponseBody1$inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody1, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigBackupResponseBody1$Outbound = {
    id: string;
    lastModified: number;
    backup: Backup$Outbound;
    metadata: Metadata$Outbound;
    user?: GetEdgeConfigBackupResponseBodyUser$Outbound | undefined;
};
/** @internal */
export declare const GetEdgeConfigBackupResponseBody1$outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody1$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBody1>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigBackupResponseBody1$ {
    /** @deprecated use `GetEdgeConfigBackupResponseBody1$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody1, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigBackupResponseBody1$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody1$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBody1>;
    /** @deprecated use `GetEdgeConfigBackupResponseBody1$Outbound` instead. */
    type Outbound = GetEdgeConfigBackupResponseBody1$Outbound;
}
export declare function getEdgeConfigBackupResponseBody1ToJSON(getEdgeConfigBackupResponseBody1: GetEdgeConfigBackupResponseBody1): string;
export declare function getEdgeConfigBackupResponseBody1FromJSON(jsonString: string): SafeParseResult<GetEdgeConfigBackupResponseBody1, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigBackupResponseBody$inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigBackupResponseBody$Outbound = GetEdgeConfigBackupResponseBody1$Outbound | GetEdgeConfigBackupResponseBody2$Outbound;
/** @internal */
export declare const GetEdgeConfigBackupResponseBody$outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBody>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigBackupResponseBody$ {
    /** @deprecated use `GetEdgeConfigBackupResponseBody$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigBackupResponseBody$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigBackupResponseBody$Outbound, z.ZodTypeDef, GetEdgeConfigBackupResponseBody>;
    /** @deprecated use `GetEdgeConfigBackupResponseBody$Outbound` instead. */
    type Outbound = GetEdgeConfigBackupResponseBody$Outbound;
}
export declare function getEdgeConfigBackupResponseBodyToJSON(getEdgeConfigBackupResponseBody: GetEdgeConfigBackupResponseBody): string;
export declare function getEdgeConfigBackupResponseBodyFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigBackupResponseBody, SDKValidationError>;
//# sourceMappingURL=getedgeconfigbackupop.d.ts.map