import * as z from "zod";
import { ClosedEnum } from "../types/enums.js";
import { Result as SafeParseResult } from "../types/fp.js";
import { SDKValidationError } from "./sdkvalidationerror.js";
export type GetEdgeConfigRequest = {
    edgeConfigId: string;
    /**
     * The Team identifier to perform the request on behalf of.
     */
    teamId?: string | undefined;
    /**
     * The Team slug to perform the request on behalf of.
     */
    slug?: string | undefined;
};
/**
 * Keeps track of the current state of the Edge Config while it gets transferred.
 */
export type GetEdgeConfigTransfer = {
    fromAccountId: string;
    startedAt: number;
    doneAt: number | null;
};
export type GetEdgeConfigSchema = {};
export declare const GetEdgeConfigPurposeEdgeConfigType: {
    readonly Experimentation: "experimentation";
};
export type GetEdgeConfigPurposeEdgeConfigType = ClosedEnum<typeof GetEdgeConfigPurposeEdgeConfigType>;
export type GetEdgeConfigPurpose2 = {
    type: GetEdgeConfigPurposeEdgeConfigType;
    resourceId: string;
};
export declare const GetEdgeConfigPurposeType: {
    readonly Flags: "flags";
};
export type GetEdgeConfigPurposeType = ClosedEnum<typeof GetEdgeConfigPurposeType>;
export type GetEdgeConfigPurpose1 = {
    type: GetEdgeConfigPurposeType;
    projectId: string;
};
export type GetEdgeConfigPurpose = GetEdgeConfigPurpose1 | GetEdgeConfigPurpose2;
/**
 * The EdgeConfig.
 */
export type GetEdgeConfigResponseBody = {
    createdAt?: number | undefined;
    updatedAt?: number | undefined;
    id?: string | undefined;
    /**
     * Name for the Edge Config Names are not unique. Must start with an alphabetic character and can contain only alphanumeric characters and underscores).
     */
    slug?: string | undefined;
    ownerId?: string | undefined;
    digest?: string | undefined;
    /**
     * Keeps track of the current state of the Edge Config while it gets transferred.
     */
    transfer?: GetEdgeConfigTransfer | undefined;
    schema?: GetEdgeConfigSchema | undefined;
    purpose?: GetEdgeConfigPurpose1 | GetEdgeConfigPurpose2 | undefined;
    sizeInBytes: number;
    itemCount: number;
};
/** @internal */
export declare const GetEdgeConfigRequest$inboundSchema: z.ZodType<GetEdgeConfigRequest, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigRequest$Outbound = {
    edgeConfigId: string;
    teamId?: string | undefined;
    slug?: string | undefined;
};
/** @internal */
export declare const GetEdgeConfigRequest$outboundSchema: z.ZodType<GetEdgeConfigRequest$Outbound, z.ZodTypeDef, GetEdgeConfigRequest>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigRequest$ {
    /** @deprecated use `GetEdgeConfigRequest$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigRequest, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigRequest$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigRequest$Outbound, z.ZodTypeDef, GetEdgeConfigRequest>;
    /** @deprecated use `GetEdgeConfigRequest$Outbound` instead. */
    type Outbound = GetEdgeConfigRequest$Outbound;
}
export declare function getEdgeConfigRequestToJSON(getEdgeConfigRequest: GetEdgeConfigRequest): string;
export declare function getEdgeConfigRequestFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigRequest, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigTransfer$inboundSchema: z.ZodType<GetEdgeConfigTransfer, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigTransfer$Outbound = {
    fromAccountId: string;
    startedAt: number;
    doneAt: number | null;
};
/** @internal */
export declare const GetEdgeConfigTransfer$outboundSchema: z.ZodType<GetEdgeConfigTransfer$Outbound, z.ZodTypeDef, GetEdgeConfigTransfer>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigTransfer$ {
    /** @deprecated use `GetEdgeConfigTransfer$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigTransfer, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigTransfer$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigTransfer$Outbound, z.ZodTypeDef, GetEdgeConfigTransfer>;
    /** @deprecated use `GetEdgeConfigTransfer$Outbound` instead. */
    type Outbound = GetEdgeConfigTransfer$Outbound;
}
export declare function getEdgeConfigTransferToJSON(getEdgeConfigTransfer: GetEdgeConfigTransfer): string;
export declare function getEdgeConfigTransferFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigTransfer, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigSchema$inboundSchema: z.ZodType<GetEdgeConfigSchema, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigSchema$Outbound = {};
/** @internal */
export declare const GetEdgeConfigSchema$outboundSchema: z.ZodType<GetEdgeConfigSchema$Outbound, z.ZodTypeDef, GetEdgeConfigSchema>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigSchema$ {
    /** @deprecated use `GetEdgeConfigSchema$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigSchema, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigSchema$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigSchema$Outbound, z.ZodTypeDef, GetEdgeConfigSchema>;
    /** @deprecated use `GetEdgeConfigSchema$Outbound` instead. */
    type Outbound = GetEdgeConfigSchema$Outbound;
}
export declare function getEdgeConfigSchemaToJSON(getEdgeConfigSchema: GetEdgeConfigSchema): string;
export declare function getEdgeConfigSchemaFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigSchema, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigPurposeEdgeConfigType$inboundSchema: z.ZodNativeEnum<typeof GetEdgeConfigPurposeEdgeConfigType>;
/** @internal */
export declare const GetEdgeConfigPurposeEdgeConfigType$outboundSchema: z.ZodNativeEnum<typeof GetEdgeConfigPurposeEdgeConfigType>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigPurposeEdgeConfigType$ {
    /** @deprecated use `GetEdgeConfigPurposeEdgeConfigType$inboundSchema` instead. */
    const inboundSchema: z.ZodNativeEnum<{
        readonly Experimentation: "experimentation";
    }>;
    /** @deprecated use `GetEdgeConfigPurposeEdgeConfigType$outboundSchema` instead. */
    const outboundSchema: z.ZodNativeEnum<{
        readonly Experimentation: "experimentation";
    }>;
}
/** @internal */
export declare const GetEdgeConfigPurpose2$inboundSchema: z.ZodType<GetEdgeConfigPurpose2, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigPurpose2$Outbound = {
    type: string;
    resourceId: string;
};
/** @internal */
export declare const GetEdgeConfigPurpose2$outboundSchema: z.ZodType<GetEdgeConfigPurpose2$Outbound, z.ZodTypeDef, GetEdgeConfigPurpose2>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigPurpose2$ {
    /** @deprecated use `GetEdgeConfigPurpose2$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigPurpose2, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigPurpose2$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigPurpose2$Outbound, z.ZodTypeDef, GetEdgeConfigPurpose2>;
    /** @deprecated use `GetEdgeConfigPurpose2$Outbound` instead. */
    type Outbound = GetEdgeConfigPurpose2$Outbound;
}
export declare function getEdgeConfigPurpose2ToJSON(getEdgeConfigPurpose2: GetEdgeConfigPurpose2): string;
export declare function getEdgeConfigPurpose2FromJSON(jsonString: string): SafeParseResult<GetEdgeConfigPurpose2, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigPurposeType$inboundSchema: z.ZodNativeEnum<typeof GetEdgeConfigPurposeType>;
/** @internal */
export declare const GetEdgeConfigPurposeType$outboundSchema: z.ZodNativeEnum<typeof GetEdgeConfigPurposeType>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigPurposeType$ {
    /** @deprecated use `GetEdgeConfigPurposeType$inboundSchema` instead. */
    const inboundSchema: z.ZodNativeEnum<{
        readonly Flags: "flags";
    }>;
    /** @deprecated use `GetEdgeConfigPurposeType$outboundSchema` instead. */
    const outboundSchema: z.ZodNativeEnum<{
        readonly Flags: "flags";
    }>;
}
/** @internal */
export declare const GetEdgeConfigPurpose1$inboundSchema: z.ZodType<GetEdgeConfigPurpose1, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigPurpose1$Outbound = {
    type: string;
    projectId: string;
};
/** @internal */
export declare const GetEdgeConfigPurpose1$outboundSchema: z.ZodType<GetEdgeConfigPurpose1$Outbound, z.ZodTypeDef, GetEdgeConfigPurpose1>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigPurpose1$ {
    /** @deprecated use `GetEdgeConfigPurpose1$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigPurpose1, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigPurpose1$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigPurpose1$Outbound, z.ZodTypeDef, GetEdgeConfigPurpose1>;
    /** @deprecated use `GetEdgeConfigPurpose1$Outbound` instead. */
    type Outbound = GetEdgeConfigPurpose1$Outbound;
}
export declare function getEdgeConfigPurpose1ToJSON(getEdgeConfigPurpose1: GetEdgeConfigPurpose1): string;
export declare function getEdgeConfigPurpose1FromJSON(jsonString: string): SafeParseResult<GetEdgeConfigPurpose1, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigPurpose$inboundSchema: z.ZodType<GetEdgeConfigPurpose, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigPurpose$Outbound = GetEdgeConfigPurpose1$Outbound | GetEdgeConfigPurpose2$Outbound;
/** @internal */
export declare const GetEdgeConfigPurpose$outboundSchema: z.ZodType<GetEdgeConfigPurpose$Outbound, z.ZodTypeDef, GetEdgeConfigPurpose>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigPurpose$ {
    /** @deprecated use `GetEdgeConfigPurpose$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigPurpose, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigPurpose$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigPurpose$Outbound, z.ZodTypeDef, GetEdgeConfigPurpose>;
    /** @deprecated use `GetEdgeConfigPurpose$Outbound` instead. */
    type Outbound = GetEdgeConfigPurpose$Outbound;
}
export declare function getEdgeConfigPurposeToJSON(getEdgeConfigPurpose: GetEdgeConfigPurpose): string;
export declare function getEdgeConfigPurposeFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigPurpose, SDKValidationError>;
/** @internal */
export declare const GetEdgeConfigResponseBody$inboundSchema: z.ZodType<GetEdgeConfigResponseBody, z.ZodTypeDef, unknown>;
/** @internal */
export type GetEdgeConfigResponseBody$Outbound = {
    createdAt?: number | undefined;
    updatedAt?: number | undefined;
    id?: string | undefined;
    slug?: string | undefined;
    ownerId?: string | undefined;
    digest?: string | undefined;
    transfer?: GetEdgeConfigTransfer$Outbound | undefined;
    schema?: GetEdgeConfigSchema$Outbound | undefined;
    purpose?: GetEdgeConfigPurpose1$Outbound | GetEdgeConfigPurpose2$Outbound | undefined;
    sizeInBytes: number;
    itemCount: number;
};
/** @internal */
export declare const GetEdgeConfigResponseBody$outboundSchema: z.ZodType<GetEdgeConfigResponseBody$Outbound, z.ZodTypeDef, GetEdgeConfigResponseBody>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace GetEdgeConfigResponseBody$ {
    /** @deprecated use `GetEdgeConfigResponseBody$inboundSchema` instead. */
    const inboundSchema: z.ZodType<GetEdgeConfigResponseBody, z.ZodTypeDef, unknown>;
    /** @deprecated use `GetEdgeConfigResponseBody$outboundSchema` instead. */
    const outboundSchema: z.ZodType<GetEdgeConfigResponseBody$Outbound, z.ZodTypeDef, GetEdgeConfigResponseBody>;
    /** @deprecated use `GetEdgeConfigResponseBody$Outbound` instead. */
    type Outbound = GetEdgeConfigResponseBody$Outbound;
}
export declare function getEdgeConfigResponseBodyToJSON(getEdgeConfigResponseBody: GetEdgeConfigResponseBody): string;
export declare function getEdgeConfigResponseBodyFromJSON(jsonString: string): SafeParseResult<GetEdgeConfigResponseBody, SDKValidationError>;
//# sourceMappingURL=getedgeconfigop.d.ts.map