import * as z from "zod";
import { ClosedEnum } from "../types/enums.js";
import { Result as SafeParseResult } from "../types/fp.js";
import { SDKValidationError } from "./sdkvalidationerror.js";
/**
 * The project role that will be added to this Access Group.
 */
export declare const UpdateAccessGroupProjectRole: {
    readonly Admin: "ADMIN";
    readonly ProjectViewer: "PROJECT_VIEWER";
    readonly ProjectDeveloper: "PROJECT_DEVELOPER";
};
/**
 * The project role that will be added to this Access Group.
 */
export type UpdateAccessGroupProjectRole = ClosedEnum<typeof UpdateAccessGroupProjectRole>;
export type UpdateAccessGroupProjectRequestBody = {
    /**
     * The project role that will be added to this Access Group.
     */
    role: UpdateAccessGroupProjectRole;
};
export type UpdateAccessGroupProjectRequest = {
    accessGroupIdOrName: string;
    projectId: string;
    /**
     * The Team identifier to perform the request on behalf of.
     */
    teamId?: string | undefined;
    /**
     * The Team slug to perform the request on behalf of.
     */
    slug?: string | undefined;
    requestBody: UpdateAccessGroupProjectRequestBody;
};
export declare const UpdateAccessGroupProjectAccessGroupsRole: {
    readonly Admin: "ADMIN";
    readonly ProjectDeveloper: "PROJECT_DEVELOPER";
    readonly ProjectViewer: "PROJECT_VIEWER";
};
export type UpdateAccessGroupProjectAccessGroupsRole = ClosedEnum<typeof UpdateAccessGroupProjectAccessGroupsRole>;
export type UpdateAccessGroupProjectResponseBody = {
    teamId: string;
    accessGroupId: string;
    projectId: string;
    role: UpdateAccessGroupProjectAccessGroupsRole;
    createdAt: string;
    updatedAt: string;
};
/** @internal */
export declare const UpdateAccessGroupProjectRole$inboundSchema: z.ZodNativeEnum<typeof UpdateAccessGroupProjectRole>;
/** @internal */
export declare const UpdateAccessGroupProjectRole$outboundSchema: z.ZodNativeEnum<typeof UpdateAccessGroupProjectRole>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace UpdateAccessGroupProjectRole$ {
    /** @deprecated use `UpdateAccessGroupProjectRole$inboundSchema` instead. */
    const inboundSchema: z.ZodNativeEnum<{
        readonly Admin: "ADMIN";
        readonly ProjectViewer: "PROJECT_VIEWER";
        readonly ProjectDeveloper: "PROJECT_DEVELOPER";
    }>;
    /** @deprecated use `UpdateAccessGroupProjectRole$outboundSchema` instead. */
    const outboundSchema: z.ZodNativeEnum<{
        readonly Admin: "ADMIN";
        readonly ProjectViewer: "PROJECT_VIEWER";
        readonly ProjectDeveloper: "PROJECT_DEVELOPER";
    }>;
}
/** @internal */
export declare const UpdateAccessGroupProjectRequestBody$inboundSchema: z.ZodType<UpdateAccessGroupProjectRequestBody, z.ZodTypeDef, unknown>;
/** @internal */
export type UpdateAccessGroupProjectRequestBody$Outbound = {
    role: string;
};
/** @internal */
export declare const UpdateAccessGroupProjectRequestBody$outboundSchema: z.ZodType<UpdateAccessGroupProjectRequestBody$Outbound, z.ZodTypeDef, UpdateAccessGroupProjectRequestBody>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace UpdateAccessGroupProjectRequestBody$ {
    /** @deprecated use `UpdateAccessGroupProjectRequestBody$inboundSchema` instead. */
    const inboundSchema: z.ZodType<UpdateAccessGroupProjectRequestBody, z.ZodTypeDef, unknown>;
    /** @deprecated use `UpdateAccessGroupProjectRequestBody$outboundSchema` instead. */
    const outboundSchema: z.ZodType<UpdateAccessGroupProjectRequestBody$Outbound, z.ZodTypeDef, UpdateAccessGroupProjectRequestBody>;
    /** @deprecated use `UpdateAccessGroupProjectRequestBody$Outbound` instead. */
    type Outbound = UpdateAccessGroupProjectRequestBody$Outbound;
}
export declare function updateAccessGroupProjectRequestBodyToJSON(updateAccessGroupProjectRequestBody: UpdateAccessGroupProjectRequestBody): string;
export declare function updateAccessGroupProjectRequestBodyFromJSON(jsonString: string): SafeParseResult<UpdateAccessGroupProjectRequestBody, SDKValidationError>;
/** @internal */
export declare const UpdateAccessGroupProjectRequest$inboundSchema: z.ZodType<UpdateAccessGroupProjectRequest, z.ZodTypeDef, unknown>;
/** @internal */
export type UpdateAccessGroupProjectRequest$Outbound = {
    accessGroupIdOrName: string;
    projectId: string;
    teamId?: string | undefined;
    slug?: string | undefined;
    RequestBody: UpdateAccessGroupProjectRequestBody$Outbound;
};
/** @internal */
export declare const UpdateAccessGroupProjectRequest$outboundSchema: z.ZodType<UpdateAccessGroupProjectRequest$Outbound, z.ZodTypeDef, UpdateAccessGroupProjectRequest>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace UpdateAccessGroupProjectRequest$ {
    /** @deprecated use `UpdateAccessGroupProjectRequest$inboundSchema` instead. */
    const inboundSchema: z.ZodType<UpdateAccessGroupProjectRequest, z.ZodTypeDef, unknown>;
    /** @deprecated use `UpdateAccessGroupProjectRequest$outboundSchema` instead. */
    const outboundSchema: z.ZodType<UpdateAccessGroupProjectRequest$Outbound, z.ZodTypeDef, UpdateAccessGroupProjectRequest>;
    /** @deprecated use `UpdateAccessGroupProjectRequest$Outbound` instead. */
    type Outbound = UpdateAccessGroupProjectRequest$Outbound;
}
export declare function updateAccessGroupProjectRequestToJSON(updateAccessGroupProjectRequest: UpdateAccessGroupProjectRequest): string;
export declare function updateAccessGroupProjectRequestFromJSON(jsonString: string): SafeParseResult<UpdateAccessGroupProjectRequest, SDKValidationError>;
/** @internal */
export declare const UpdateAccessGroupProjectAccessGroupsRole$inboundSchema: z.ZodNativeEnum<typeof UpdateAccessGroupProjectAccessGroupsRole>;
/** @internal */
export declare const UpdateAccessGroupProjectAccessGroupsRole$outboundSchema: z.ZodNativeEnum<typeof UpdateAccessGroupProjectAccessGroupsRole>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace UpdateAccessGroupProjectAccessGroupsRole$ {
    /** @deprecated use `UpdateAccessGroupProjectAccessGroupsRole$inboundSchema` instead. */
    const inboundSchema: z.ZodNativeEnum<{
        readonly Admin: "ADMIN";
        readonly ProjectDeveloper: "PROJECT_DEVELOPER";
        readonly ProjectViewer: "PROJECT_VIEWER";
    }>;
    /** @deprecated use `UpdateAccessGroupProjectAccessGroupsRole$outboundSchema` instead. */
    const outboundSchema: z.ZodNativeEnum<{
        readonly Admin: "ADMIN";
        readonly ProjectDeveloper: "PROJECT_DEVELOPER";
        readonly ProjectViewer: "PROJECT_VIEWER";
    }>;
}
/** @internal */
export declare const UpdateAccessGroupProjectResponseBody$inboundSchema: z.ZodType<UpdateAccessGroupProjectResponseBody, z.ZodTypeDef, unknown>;
/** @internal */
export type UpdateAccessGroupProjectResponseBody$Outbound = {
    teamId: string;
    accessGroupId: string;
    projectId: string;
    role: string;
    createdAt: string;
    updatedAt: string;
};
/** @internal */
export declare const UpdateAccessGroupProjectResponseBody$outboundSchema: z.ZodType<UpdateAccessGroupProjectResponseBody$Outbound, z.ZodTypeDef, UpdateAccessGroupProjectResponseBody>;
/**
 * @internal
 * @deprecated This namespace will be removed in future versions. Use schemas and types that are exported directly from this module.
 */
export declare namespace UpdateAccessGroupProjectResponseBody$ {
    /** @deprecated use `UpdateAccessGroupProjectResponseBody$inboundSchema` instead. */
    const inboundSchema: z.ZodType<UpdateAccessGroupProjectResponseBody, z.ZodTypeDef, unknown>;
    /** @deprecated use `UpdateAccessGroupProjectResponseBody$outboundSchema` instead. */
    const outboundSchema: z.ZodType<UpdateAccessGroupProjectResponseBody$Outbound, z.ZodTypeDef, UpdateAccessGroupProjectResponseBody>;
    /** @deprecated use `UpdateAccessGroupProjectResponseBody$Outbound` instead. */
    type Outbound = UpdateAccessGroupProjectResponseBody$Outbound;
}
export declare function updateAccessGroupProjectResponseBodyToJSON(updateAccessGroupProjectResponseBody: UpdateAccessGroupProjectResponseBody): string;
export declare function updateAccessGroupProjectResponseBodyFromJSON(jsonString: string): SafeParseResult<UpdateAccessGroupProjectResponseBody, SDKValidationError>;
//# sourceMappingURL=updateaccessgroupprojectop.d.ts.map